ActiveSpeakerSourceRole

Enum ActiveSpeakerSourceRole 

pub enum ActiveSpeakerSourceRole {
    Detector,
    Promotable,
}
role one source plays inside an active-speaker group

Variants



Detector

transport observations from this source can mark its owner active

detectors are usually audio-like and do not receive video layout treatment by themselves



Promotable

this source can receive active-speaker video treatment for its owner

core promotes it only when a detector in the same group marks the same owner as active